@@ -313,7 +313,7 @@ binom_PCC <- function( data = NULL, n = NULL, historical_data = NULL,
   }
 
   # List of results
-  if ( summary_list ) { print(PCC_summary) }
+  if ( summary_list ) { return(PCC_summary) }
 
 
   # List of results return in pdf
