@@ -291,7 +291,7 @@ nbinom_PCC <- function( data = NULL, historical_data = NULL,
   }
 
   # List of results
-  if ( summary_list ) { print(PCC_summary) }
+  if ( summary_list ) { return(PCC_summary) }
 
 
   # List of results return in pdf
